@@ -3,7 +3,7 @@ use warnings;
 use strict;
 
 use URI;
-use parent qw(App::CLI::Command);
+use base qw(App::CLI::Command);
 use Vimana::Logger;
 
 sub options {
@@ -14,11 +14,13 @@ sub options {
 
 
 require Vimana::VimOnline;
+require Vimana::VimOnline::Search;
+require Vimana::VimOnline::ScriptPage;
 
 sub fetch_index {
     return Vimana::VimOnline::Search->fetch(
         keyword => '',
-        show_me => Vimana::VimOnline::Search->all_vim_plugins,
+        show_me => 3000,
         order_by => 'creation_date',
         direction => 'ascending'
     );
